# RTLS API Gateway

## Common

### Description

This GitHub repository contains a web server that is called as `RTLS API Gateway`.
The component is implementing gateway logic proxying http requests from the client to
the `Historical`, `Operational`, `Platform` REST API servers.
Result of package building is rpm package `rtls-api-gateway_yyyy.x.xx-x_amd64.deb `.

### Documentation

[gateway configuration](./config/gateway.config.yml)

### Technologies

- `rtls-api-gateway`: NodeJs, express-gateway

### Requirements

- Ubuntu 22.04
- NodeJs v20

### Project local setup

- clone git repository
- create folders and files:

```shell
cp .env.defaults .env

```

- update `.env` file to change environment variables
- install `NodeJs` via `nvm`

```shell
curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.3/install.sh | bash
nvm install 20.5.1

```

- or install `NodeJs`

```shell
curl -fsSL https://deb.nodesource.com/setup_20.x | sudo bash -
apt-get install -y nodejs

```

- install server node packages `npm install`
- run server `npm start`, by default server port is `8082`

## Conventions

### Code style

#### Formatting rules

- please, follow the eslint rules described in project (with this purpose setting up your IDE with the ```eslint.rc```);

#### Naming rules

- please name the variables and constants in a human-readable manner (ex. use `getUsersSql` instead of `sql1`);
- please use the `camelCase` style in name the variables and constants (ex. `getUsersSql` instead of `get_users_sql`);
- please use upper case naming for constants that are not changeable in project (ex. `MAX_ROWS_NUMBER`);
- please use `JavaScript` conventions in naming the classes, constructors(functions) and others entities (classes should
  be named wih the first capital latter);
